@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for Scryer Prolog
-%  Last updated on May 4, 2021
+%  Last updated on May 16, 2021
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2021 Paulo Moura <pmoura@logtalk.org>
@@ -277,7 +277,13 @@
 '$lgt_default_flag'(events, deny).
 '$lgt_default_flag'(context_switching_calls, allow).
 % other compilation flags:
-'$lgt_default_flag'(scratch_directory, './lgt_tmp/').
+'$lgt_default_flag'(scratch_directory, ScratchDirectory) :-
+	(	getenv("COMSPEC", _) ->
+		% Windows systems define this environment variable...
+		ScratchDirectory = './lgt_tmp/'
+	;	% ... but not POSIX systems
+		ScratchDirectory = './.lgt_tmp/'
+	).
 '$lgt_default_flag'(report, on).
 '$lgt_default_flag'(clean, on).
 '$lgt_default_flag'(code_prefix, '$').
@@ -481,7 +487,8 @@
 
 % '$lgt_stream_current_line_number'(@stream, -integer)
 
-'$lgt_stream_current_line_number'(_, -1).
+'$lgt_stream_current_line_number'(Stream, Line) :-
+	stream_property(Stream, position(position_and_lines_read(_, Line))).
 
 
 
@@ -517,8 +524,10 @@
 
 % '$lgt_read_term'(@stream, -term, +list, -position, -list)
 
-'$lgt_read_term'(Stream, Term, Options, '-'(-1, -1)) :-
-	read_term(Stream, Term, Options).
+'$lgt_read_term'(Stream, Term, Options, LineBegin-LineEnd) :-
+	stream_property(Stream, position(position_and_lines_read(_, LineBegin))),
+	read_term(Stream, Term, Options),
+	stream_property(Stream, position(position_and_lines_read(_, LineEnd))).
 
 
 
@@ -567,8 +576,10 @@
 
 % '$lgt_copy_term_without_constraints'(@term, ?term)
 
+:- use_module(library(iso_ext), [copy_term_nat/2]).
+
 '$lgt_copy_term_without_constraints'(Term, Copy) :-
-	copy_term(Term, Copy).
+	copy_term_nat(Term, Copy).
 
 
 
@@ -673,7 +684,12 @@ term_hash(_, _, _, _) :-
 
 % '$lgt_user_module_qualification'(@callable, -callable)
 
-'$lgt_user_module_qualification'(Goal, Goal).
+:- dynamic('$lgt_user_module_qualification'/2).
+
+:- initialization((
+	prolog_load_context(module, Module),
+	assertz('$lgt_user_module_qualification'(Goal, Module:Goal))
+)).
 
 
 
