@@ -3,7 +3,7 @@
 #############################################################################
 ## 
 ##   Logtalk backend Prolog compiler select script
-##   Last updated on January 3, 2021
+##   Last updated on May 4, 2021
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
 ##   Copyright 1998-2021 Paulo Moura <pmoura@logtalk.org>
@@ -26,7 +26,7 @@
 
 print_version() {
 	echo "Current $(basename "$0") version:"
-	echo "  0.11"
+	echo "  0.12"
 	exit 0
 }
 
@@ -54,6 +54,9 @@ list_backends() {
 	if [ -e "$(command -v lvmlgt)" ] && [ "$(command -v lvm)" != "" ] ; then
 		echo -n "  lvmlgt"
 	fi
+	if [ -e "$(command -v scryerlgt)" ] && [ "$(command -v scryer-prolog)" != "" ] ; then
+		echo -n "  scryerlgt"
+	fi
 	if [ -e "$(command -v sicstuslgt)" ] && [ "$(command -v sicstus)" != "" ] ; then
 		echo -n "  sicstuslgt"
 	fi
@@ -143,6 +146,8 @@ valid_backend() {
 		return 0
 	elif [ "$1" == "lvmlgt" ] && [ -e "$(command -v lvmlgt)" ]  && [ "$(command -v lvm)" != "" ] ; then
 		return 0
+	elif [ "$1" == "scryerlgt" ] && [ -e "$(command -v scryerlgt)" ]  && [ "$(command -v scryer-prolog)" != "" ] ; then
+		return 0
 	elif [ "$1" == "sicstuslgt" ] && [ -e "$(command -v sicstuslgt)" ]  && [ "$(command -v sicstus)" != "" ] ; then
 		return 0
 	elif [ "$1" == "swilgt" ] && [ -e "$(command -v swilgt)" ]  && [ "$(command -v swipl)" != "" ] ; then
