@@ -3,7 +3,7 @@
 #############################################################################
 ## 
 ##   Logtalk uninstall script
-##   Last updated on January 11, 2021
+##   Last updated on May 4, 2021
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
 ##   Copyright 1998-2021 Paulo Moura <pmoura@logtalk.org>
@@ -84,6 +84,7 @@ rm -f logtalk_user_setup
 rm -f logtalk_version_select
 rm -f lvmlgt
 rm -f quintuslgt
+rm -f scryerlgt
 rm -f sicstuslgt
 rm -f swilgt
 rm -f taulgt
@@ -111,6 +112,7 @@ rm -f logtalk_user_setup.1.gz
 rm -f logtalk_version_select.1.gz
 rm -f lvmlgt.1.gz
 rm -f quintuslgt.1.gz
+rm -f scryerlgt.1.gz
 rm -f sicstuslgt.1.gz
 rm -f swilgt.1.gz
 rm -f taulgt.1.gz
